==> libqapt-1.2.80.tar.bz2: libqapt-1.2.80/example/commitwidget.h <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef COMMITWIDGET_H
#define COMMITWIDGET_H

#include <KVBox>

class QLabel;
class QProgressBar;

class CommitWidget : public KVBox
{
    Q_OBJECT
public:
    CommitWidget(QWidget *parent = 0);
    ~CommitWidget();

    void setLabelText(const QString &text);
    void setProgress(int percentage);
    void clear();

private:
    QLabel *m_commitLabel;
    QProgressBar *m_progressBar;
};

#endif

==> libqapt-1.9.65.tar.bz2: libqapt-1.9.65/example/commitwidget.h <==
/***************************************************************************
 *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef COMMITWIDGET_H
#define COMMITWIDGET_H

#include <KVBox>

class QLabel;
class QProgressBar;

namespace QApt {
    class Transaction;
}

class CommitWidget : public KVBox
{
    Q_OBJECT
public:
    CommitWidget(QWidget *parent = 0);

    void setTransaction(QApt::Transaction *trans);
    void clear();

private:
    QApt::Transaction *m_trans;

    QLabel *m_commitLabel;
    QProgressBar *m_progressBar;
};

#endif
